@@ -7,6 +7,6 @@ See ADR ``docs/decisions/0006-public-api-and-app-organization.rst`` for the reas
 """
 
 from edx_event_bus_kafka.internal.consumer import KafkaEventConsumer
-from edx_event_bus_kafka.internal.producer import KafkaEventProducer, get_producer
+from edx_event_bus_kafka.internal.producer import KafkaEventProducer, create_producer
 
-__version__ = '1.10.0'
+__version__ = '2.0.0'
